@@ -10,7 +10,7 @@ use EPublisher::Config;
 use EPublisher::Source;
 use EPublisher::Target;
 
-our $VERSION = 0.3;
+our $VERSION = 0.4;
 
 sub new{
     my ($class,%args) = @_;
@@ -65,9 +65,9 @@ sub run{
             $source_obj->publisher( $self );
             
             my @pod_source = $source_obj->load_source;
-            @pod_source = ('') if !@pod_source;
+            @pod_source = ({ pod => '', title => '', filename => '' }) if !@pod_source;
             
-            $self->debug('101: ' . substr "@pod_source", 0, 50 );
+            $self->debug('101: ' . substr join( "", map{ $_->{pod} }@pod_source ), 0, 50 );
             
             push @pods, @pod_source;
         }        
@@ -116,7 +116,8 @@ sub _config{
 1;
 
 
-__END__
+
+
 =pod
 
 =head1 NAME
@@ -125,7 +126,7 @@ EPublisher - Publish documents in new format
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 SYNOPSIS
 
@@ -195,6 +196,14 @@ converts POD to plain text.
 
 L<EPublisher::Target::Base> describes how you can write your own Target-Plugin.
 
+=head1 NAME
+
+EPublisher - Publish documents in new format
+
+=head1 VERSION
+
+version 0.4
+
 =head1 METHODS
 
 All methods available for EPublisher are described in the subsequent sections
@@ -247,9 +256,24 @@ Renee Baecker <module@renee-baecker.de>
 
 This software is Copyright (c) 2012 by Renee Baecker.
 
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
+=head1 AUTHOR
+
+Renee Baecker <module@renee-baecker.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Renee Baecker.
+
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
 
+
+__END__
+
