@@ -6,13 +6,14 @@ use strict;
 use warnings;
 
 use File::Find::Rule;
+use File::Basename;
 
 use EPublisher::Source::Base;
 use EPublisher::Utils::PPI qw(extract_pod);
 
 our @ISA = qw( EPublisher::Source::Base );
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub load_source{
     my ($self) = @_;
@@ -34,8 +35,16 @@ sub load_source{
         my $pod = extract_pod( $file );
         
         next FILE if !$pod;
+
+        my $filename = basename $file;
+        my $title    = $filename;
+
+        if ( $options->{title} and $options->{title} eq 'pod' ) {
+            ($title) = $pod =~ m{ =head1 \s+ (.*) }x;
+            $title = '' if !defined $title;
+        }
         
-        push @pods, $pod;
+        push @pods, { pod => $pod, title => $title, filename => $filename };
     }
     
     return @pods;
@@ -53,11 +62,11 @@ EPublisher::Source::Plugin::Dir - Dir source plugin
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 SYNOPSIS
 
-  my $source_options = { type => 'File', path => '/var/lib/CGI.pm' };
+  my $source_options = { type => 'Dir', path => '/var/lib/' };
   my $file_source    = EPublisher::Source->new( $source_options );
   my $pod            = $File_source->load_source;
 
@@ -67,18 +76,32 @@ version 0.3
 
   my $pod = $file_source->load_source;
 
-reads the File 
+checks all pod/pm/pl files in the given directory (and its subdirectories)
+and returns information about those files:
+
+  (
+      {
+          pod      => $pod_document,
+          filename => $file,
+          title    => $title,
+      },
+  )
+
+C<$pod_document> is the complete pod documentation that was found in the file.
+C<$file> is the name of the file (without path) and C<$title> is the title of
+the pod documentation. By default it is the filename, but you can say "title => 'pod'"
+in the configuration. The title is the first value for I<=head1> in the pod.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Renee Baecker, all rights reserved.
+Copyright 2010 - 2012 Renee Baecker, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of Artistic License 2.0.
 
 =head1 AUTHOR
 
-Renee Baecker (E<lt>File@renee-baecker.deE<gt>)
+Renee Baecker (E<lt>module@renee-baecker.deE<gt>)
 
 =head1 AUTHOR
 
